@@ -1,11 +1,16 @@
 package Task::MusicBundle;
+
 BEGIN {
   $Task::MusicBundle::AUTHORITY = 'cpan:GENE';
 }
+
 # ABSTRACT: A bundle of MIDI and music modules
+
 use strict;
 use warnings;
-our $VERSION = '0.16';
+
+our $VERSION = '0.1700';
+
 1;
 
 __END__
@@ -20,10 +25,12 @@ Task::MusicBundle - A bundle of MIDI and music modules
 
 =head1 VERSION
 
-version 0.16
+version 0.1700
 
 =head1 SYNOPSIS
 
+ cpanm Task::MusicBundle
+ # or
  cpan Task::MusicBundle
  # or
  perl -MCPAN -e 'install Task::MusicBundle'
@@ -76,6 +83,8 @@ L<MIDI::Trans> - May 24, 2002
 
 L<MIDI::Tweaks>
 
+L<MIDI::Util>
+
 L<Music::AtonalUtil>
 
 L<Music::Canon>
